﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using uPLibrary.Networking.M2Mqtt;
using uPLibrary.Networking.M2Mqtt.Messages;

namespace AdapayCore
{
    public delegate void MQTTMsgRecEventHandler(string message);
    public class MQTTServerClient
    {
        public static string deviceId = "";
        public static MqttClient client = null;

        public static MerConfig _config = null;

        public static event MQTTMsgRecEventHandler msgReceiveHandler;
        public static void instanceClient(MerConfig config) {

            _config = config;

            string token = applyToken(_config);
            //实例 ID，购买后从控制台获取
            string instanceId = MQTT_Config.MQTT_INSTANCE_ID;
            //此处填写购买得到的 MQTT 接入点域名
            string brokerUrl = MQTT_Config.MQTT_END_POINT;
            //此处填写阿里云帐号 AccessKey
            string accessKey = MQTT_Config.MQTT_ACCESS_KEY;
            string topic = MQTT_Config.MQTT_TOPIC_PREFIX + _config.apiKey;

            string clientId = MQTT_Config.MQTT_CLIENT_ID_PREFIX + CoreUtils.GetMD5Hash(_config.apiKey+ MQTTServerClient.deviceId);
            
            
            try
            {
               client  = new MqttClient(brokerUrl);
            }
            catch (Exception e)
            {

                throw e;
            }
            
            client.MqttMsgPublishReceived += Client_MqttMsgPublishReceived;


            client.ConnectionClosed += client_connectLose;
            client.MqttMsgSubscribed += Client_MqttMsgSubscribed;
            
            string userName = "Token|" + accessKey + "|" + instanceId;
            string passWord = "R|"+token;

            try
            {
                client.Connect(clientId, userName, passWord, false, 60);
            }
            catch (Exception e)
            {
                throw e;
            }
            if(CoreUtils.debug)
            {
                CoreUtils.Log("topic==========" + topic);
                CoreUtils.Log("clientId=================" + clientId);

            }


            string[] subTopicArray = { topic };
            byte[] qosLevels = { MqttMsgBase.QOS_LEVEL_AT_LEAST_ONCE };
            client.Subscribe(subTopicArray, qosLevels);

        }

        private static void Client_MqttMsgPublishReceived(object sender, MqttMsgPublishEventArgs e)
        {

            if (CoreUtils.debug)
            {
                CoreUtils.Log("Recv Msg : Topic is " + e.Topic + " ,Body is " + Encoding.UTF8.GetString(e.Message));
            }
            if (msgReceiveHandler == null) {
                throw new NotImplementedException("msgReceiveHandler cannot be null");
            }
            msgReceiveHandler(Encoding.UTF8.GetString(e.Message));
        }

        private static void Client_MqttMsgSubscribed(object sender, MqttMsgSubscribedEventArgs e)
        {

            CoreUtils.Log("subscribed success");
            CoreUtils.Log("is connect" + client.IsConnected);

            if (msgReceiveHandler == null)
            {
                throw new NotImplementedException("msgReceiveHandler cannot be null");
            }
            msgReceiveHandler("subscribed success");

        }
        
        static void client_connectLose(object sender, EventArgs e)
        {
            MQTTServerClient.instanceClient(_config);
            CoreUtils.Log("Connect Lost,Try Reconnect");
            if (msgReceiveHandler == null)
            {
                throw new NotImplementedException("msgReceiveHandler cannot be null");
            }
            msgReceiveHandler( "Connect Lost,Try Reconnect");
        }

        static string applyToken(MerConfig config) {

            Dictionary<string, object> requestDict = new Dictionary<string, object>();
            requestDict.Add("expire_time", "864000");
            object token = null;
            Dictionary<string, Object> tokenResponse = NetUtils.requestAdapay(requestDict, MQTT_Config.TOKEN_APPLY_V1, NetUtils.POST, config.apiKey,config.privateKey);
            try
            {
                tokenResponse.TryGetValue("token",out token);
                if (string.IsNullOrEmpty((string)token))
                {
                    throw new Exception("token 获取失败");
                }
                CoreUtils.Log("token......." + token);
                
            }
            catch (Exception)
            {

                throw new Exception("token 获取失败");
            }
            return (string)token;

        }
    }
}
