﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;



namespace AdapaySDK
{
    public class Member
    {
        /**
         * 创建用户对象
         *
         * @param requestParams 创建用户对象的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 创建用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams, string merchantKey)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.MEMBER_V1, merchantKey);
        }

        /**
         * 查询用户对象
         *
         * @param requestParams 查询用户对象的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 查询的用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams, string merchantKey)
        {

            string memberId = StringUtils.tryGetNotNullValue(requestParams,"member_id");
            string uri = new StringBuilder(APIUrlEnum.QUERY_MEMBER_V1).Append(memberId).ToString();
            return AdapayRequest.getRequestAdapay(requestParams, uri, merchantKey);
        }

        /**
         * 查询用户列表
         *
         * @param requestParams 查询用户列表的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 查询的用户列表
         * @ 异常
         */
        public static Dictionary<string, Object> queryList(Dictionary<string, object> requestParams, string merchantKey)
        {

            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_MEMBER_LIST_V1, merchantKey);
        }

        /**
         * 更新用户对象
         *
         * @param requestParams 更新用户对象的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 更新后的用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> update(Dictionary<string, object> requestParams, string merchantKey)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.UPDATE_MEMBER_V1, merchantKey);
        }


        /**
         * 创建用户对象
         *
         * @param requestParams 创建用户对象的请求参数，参见 AdaPay api
         * @return 创建用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.MEMBER_V1, null);
        }

        /**
         * 查询用户对象
         *
         * @param requestParams 查询用户对象的请求参数，参见 AdaPay api
         * @return 查询的用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams)
        {
            string memberId = StringUtils.tryGetNotNullValue(requestParams, "member_id");
            string uri = new StringBuilder(APIUrlEnum.QUERY_MEMBER_V1).Append(memberId).ToString();
            return AdapayRequest.getRequestAdapay(requestParams, uri, null);
        }

        /**
         * 查询用户列表
         *
         * @param requestParams 查询用户列表的请求参数，参见 AdaPay api
         * @return 查询的用户列表
         * @ 异常
         */
        public static Dictionary<string, Object> queryList(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.QUERY_MEMBER_LIST_V1, null);
        }

        /**
         * 更新用户对象
         *
         * @param requestParams 更新用户对象的请求参数，参见 AdaPay api
         * @return 更新后的用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> update(Dictionary<string, object> requestParams)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.UPDATE_MEMBER_V1, null);
        }

    }

    public class CorpMember
    {
        /**
         * 创建企业用户对象
         *
         * @param params 创建企业用户对象的请求参数，参见 AdaPay api
         * @param params 创建企业用户对象的附件文件参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 创建用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams, string filePath, string merchantKey)
        {

            return AdapayRequest.requestAdapay(requestParams, filePath, "attach_file", APIUrlEnum.CORP_MEMBER_V1, merchantKey);
        }

        /**
         * 查询企业用户对象
         *
         * @param params 查询企业用户对象的请求参数，参见 AdaPay api
         * @return 查询的企业用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams, string merchantKey)
        {
            string memberId = StringUtils.tryGetNotNullValue(requestParams, "member_id");
            string uri = new StringBuilder(APIUrlEnum.QUERY_CORP_MEMBER_V1).Append(memberId).ToString();

            return AdapayRequest.getRequestAdapay(requestParams, uri,  merchantKey);
        }

        /**
         * 创建企业用户对象
         *
         * @param params 创建企业用户对象的请求参数，参见 AdaPay api
         * @param params 创建企业用户对象的附件文件参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 创建用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams, string filePath)
        {
            
            return AdapayRequest.requestAdapay(requestParams, filePath, "attach_file",  APIUrlEnum.CORP_MEMBER_V1,  null);
        }

        /**
         * 查询企业用户对象
         *
         * @param params 查询企业用户对象的请求参数，参见 AdaPay api
         * @return 查询的企业用户对象
         * @ 异常
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams)
        {
            string memberId = StringUtils.tryGetNotNullValue(requestParams, "member_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_CORP_MEMBER_V1).Append(memberId).ToString();
            return AdapayRequest.getRequestAdapay(requestParams, uri,  null);
        }

    }

    public class SettleAccount
    {
        /**
         * 创建结算账户对象
         *
         * @param params 创建结算账户对象的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 创建结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams, string merchantKey)
        {
            
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.SETTLE_ACCOUNT_V1,  merchantKey);
        }

        /**
         * 查询结算账户对象
         *
         * @param params 查询结算账户对象的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 查询的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams, string merchantKey)
        {
            string settleAccountId = StringUtils.tryGetNotNullValue(requestParams, "settle_account_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_SETTLE_ACCOUNT_V1).Append(settleAccountId).ToString();

            return AdapayRequest.getRequestAdapay(requestParams, uri,  merchantKey);
        }

        /**
         * 删除结算账户对象
         *
         * @param params 删除结算账户对象的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 删除的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> delete(Dictionary<string, object> requestParams, string merchantKey)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.DELETE_SETTLE_ACCOUNT_V1,  merchantKey);
        }

        /**
         * 查询结算明细列表
         *
         * @param params 查询结算明细列表的请求参数，参见 AdaPay api
         * @param merchantKey merchantKey
         * @return 查询的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> querySettleDetails(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_SETTLE_DETAILS_V1,  merchantKey);
        }

        /**
         * 创建结算账户对象
         *
         * @param params 创建结算账户对象的请求参数，参见 AdaPay api
         * @return 创建结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.SETTLE_ACCOUNT_V1,  null);
        }

        /**
         * 查询结算账户对象
         *
         * @param params 查询结算账户对象的请求参数，参见 AdaPay api
         * @return 查询的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams)
        {
            string settleAccountId = StringUtils.tryGetNotNullValue(requestParams, "settle_account_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_SETTLE_ACCOUNT_V1).Append(settleAccountId).ToString();

            return AdapayRequest.getRequestAdapay(requestParams, uri,  null);
        }

        /**
         * 删除结算账户对象
         *
         * @param params 删除结算账户对象的请求参数，参见 AdaPay api
         * @return 删除的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> delete(Dictionary<string, object> requestParams)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.DELETE_SETTLE_ACCOUNT_V1,  null);
        }

        /**
         * 查询结算明细列表
         *
         * @param params 查询结算明细列表的请求参数，参见 AdaPay api
         * @return 查询的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> querySettleDetails(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_SETTLE_DETAILS_V1,  null);
        }

        /**
         * 修改结算明细列表
         *
         * @param params 修改结算明细列表的请求参数，参见 AdaPay api
         * @return 修改的结算账户对象
         * @ 异常
         */
        public static Dictionary<string, Object> modify(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.MODIFY_SETTLE_ACCOUNT_V1, null);
        }

        /**
         * 查询帐户余额
         *
         * @param params 查询帐户余额的请求参数，参见 AdaPay api
         * @return 帐户余额
         */
        public static Dictionary<string, Object> queryBalance(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_BALANCE, null);
        }

        /**
         * 查询帐户余额
         *
         * @param params 查询帐户余额的请求参数，参见 AdaPay api
         * @return 帐户余额
         */
        public static Dictionary<string, Object> queryBalance(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_BALANCE, merchantKey);
        }

        /**
         * 查询帐户余额
         *
         * @param params 查询帐户余额的请求参数，参见 AdaPay api
         * @return 帐户余额
         */
        public static Dictionary<string, Object> drawCash(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.DRAW_CASH, null);
        }

        /**
         * 查询帐户余额
         *
         * @param params 查询帐户余额的请求参数，参见 AdaPay api
         * @return 帐户余额
         */
        public static Dictionary<string, Object> drawCash(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.DRAW_CASH, merchantKey);
        }

        /**
         * 查询取现状态
         *
         * @param params 查询取现状态，参见 AdaPay api
         * @return 取现状态
         */
        public static Dictionary<string, Object> queryDrawCash(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_CASHS_STAT_V1, null);
        }

        /**
         * 查询取现状态
         *
         * @param params 查询取现状态，参见 AdaPay api
         * @return 取现状态
         */
        public static Dictionary<string, Object> queryDrawCash(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.QUERY_CASHS_STAT_V1, merchantKey);
        }
        /**
        * 用户登录
        *
        * @param params 用户登录的请求参数，参见 AdaPay api
        * @return 用户登录
        */
        public static Dictionary<string, Object> login(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.MEMBER_LOGIN, merchantKey);
        }

        /**
        * 用户登录
        *
        * @param params 用户登录的请求参数，参见 AdaPay api
        * @return 用户登录
        */
        public static Dictionary<string, Object> login(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.MEMBER_LOGIN, null);
        }

    }

}
