﻿using System;
using System.Collections.Generic;
using AdapayCore;
using System.Text;

namespace AdapaySDK
{

    public class Payment
    {
        /**
        * 创建一个支付交易
        *
        * @param requestParams      创建支付的请求参数，参见 AdaPay api
        * @param merchantKey merchantKey
        * @return 创建的支付对象
        */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams, string merchantKey)
        {
            object currency = null;
            requestParams.TryGetValue("currency", out currency);

            if (currency == null) {
                requestParams.Add("currency", "cny");
            }

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.PAYMENT_V1, merchantKey);
        }

        /**
         * create Payment
         */
        public static Dictionary<string, Object> create(Dictionary<string, object> requestParams)
        {
            object currency = null;
            requestParams.TryGetValue("currency", out currency);

            if (currency == null)
            {
                requestParams.Add("currency", "cny");
            }

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.PAYMENT_V1, null);

        }


        /**
         * 关闭一个支付
         *
         * @param requestParams   要关闭的支付id
         * @param merchantKey merchantKey
         * @return 关闭的支付对象
         */
        public static Dictionary<string, Object> close(Dictionary<string, object> requestParams, string merchantKey)
        {
            string paymentId = StringUtils.tryGetNotNullValue(requestParams, "payment_id");
            
            string uri = new StringBuilder(APIUrlEnum.CLOSE_PAYMENT_V1).Append(paymentId).Append("/close").ToString();

            //requestParams.Remove("payment_id");
            return AdapayRequest.requestAdapay(requestParams, uri, merchantKey);
        }

        /**
         * 关闭一个支付
         *
         * @param requestParams          要关闭的支付id
         * @param merchantKey merchantKey
         * @return 关闭的支付对象
         */
        public static Dictionary<string, Object> close(Dictionary<string, object> requestParams)
        {
            string paymentId = StringUtils.tryGetNotNullValue(requestParams, "payment_id");

            string uri = new StringBuilder(APIUrlEnum.CLOSE_PAYMENT_V1).Append(paymentId).Append("/close").ToString();

            //requestParams.Remove("payment_id");
            return AdapayRequest.requestAdapay(requestParams, uri, null);
        }


        /**
         * 查询已有的支付信息
         * @param requestParams          要查询的支付参数
         * @param merchantKey merchantKey
         * @return 查询的支付对象
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams, string merchantKey)
        {
            string paymentId = StringUtils.tryGetNotNullValue(requestParams, "payment_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_PAYMENT_V1).Append(paymentId).ToString();

            //requestParams.Remove("payment_id");

            return AdapayRequest.getRequestAdapay(requestParams, uri, merchantKey);
        }

        /**
         * 查询已有的支付信息
         *
         * @param requestParams          要查询的支付id
         * @return 查询的支付对象
         */
        public static Dictionary<string, Object> query(Dictionary<string, object> requestParams)
        {
            string paymentId = StringUtils.tryGetNotNullValue(requestParams, "payment_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_PAYMENT_V1).Append(paymentId).ToString();

            //requestParams.Remove("payment_id");

            return AdapayRequest.getRequestAdapay(requestParams, uri, null);
        }


        /**
         * 创建撤销对象
         *
         * @param requestParams      创建支付撤销对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付对象
         */
        public static Dictionary<string, Object> createReverse(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.REVERSE_PAYMENT_V1, merchantKey);
        }

        /**
         * 创建撤销对象
         *
         * @param requestParams      创建支付撤销对象参数
         * @return 查询的支付对象
         */
        public static Dictionary<string, Object> createReverse(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.REVERSE_PAYMENT_V1, null);
        }


        /**
         * 查询已有的支付撤销对象列表
         *
         * @param requestParams      要查询的支付撤销对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryReverseList(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.REVERSE_PAYMENT_LIST_V1, merchantKey);
        }

        /**
         * 查询已有的支付撤销对象列表
         *
         * @param requestParams      要查询的支付撤销对象参数
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryReverseList(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.REVERSE_PAYMENT_LIST_V1, null);
        }


        /**
         * 查询已有的支付撤销对象
         *
         * @param requestParams      要查询的支付撤销对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryReverse(Dictionary<string, object> requestParams, string merchantKey)
        {
            string reverseId = StringUtils.tryGetNotNullValue(requestParams, "reverse_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_REVERSE_PAYMENT_V1).Append(reverseId).ToString();
            return AdapayRequest.getRequestAdapay( requestParams, uri, merchantKey);
        }

        /**
         * 查询已有的支付撤销对象
         *
         * @param requestParams      要查询的支付撤销对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryReverse(Dictionary<string, object> requestParams)
        {
            string reverseId = StringUtils.tryGetNotNullValue(requestParams, "reverse_id");
            
            string uri = new StringBuilder(APIUrlEnum.QUERY_REVERSE_PAYMENT_V1).Append(reverseId).ToString();
            return AdapayRequest.getRequestAdapay(requestParams, uri, null);
        }


        /**
         * 创建支付确认对象
         *
         * @param requestParams      创建支付确认对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付对象
         */
        public static Dictionary<string, Object> createConfirm(Dictionary<string, object> requestParams, string merchantKey)
        {

            return AdapayRequest.requestAdapay( requestParams, APIUrlEnum.CONFIRM_PAYMENT_V1, merchantKey);
        }

        /**
         * 创建支付确认对象
         *
         * @param requestParams      创建支付确认对象参数
         * @return 查询的支付对象
         */
        public static Dictionary<string, Object> createConfirm(Dictionary<string, object> requestParams)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.CONFIRM_PAYMENT_V1, null);
        }


        /**
         * 查询已有的支付确认对象列表
         *
         * @param requestParams      要查询的支付撤销对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryConfirmList(Dictionary<string, object> requestParams, string merchantKey)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.CONFIRM_PAYMENT_LIST_V1,  merchantKey);
        }

        /**
         * 查询已有的支付确认对象列表
         *
         * @param requestParams      要查询的支付撤销对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryConfirmList(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.CONFIRM_PAYMENT_LIST_V1, null);
        }



        /**
         * 查询已有的支付确认对象
         *
         * @param requestParams      要查询的支付确认对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryConfirm(Dictionary<string, object> requestParams, string merchantKey)
        {
            string paymentConfirmId = StringUtils.tryGetNotNullValue(requestParams, "payment_confirm_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_CONFIRM_PAYMENT_V1).Append(paymentConfirmId).ToString();

            return AdapayRequest.getRequestAdapay(requestParams,uri, merchantKey);
        }

        /**
         * 查询已有的支付确认对象
         *
         * @param requestParams      要查询的支付确认对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> queryConfirm(Dictionary<string, object> requestParams)
        {

            string paymentConfirmId = StringUtils.tryGetNotNullValue(requestParams, "payment_confirm_id");

            string uri = new StringBuilder(APIUrlEnum.QUERY_CONFIRM_PAYMENT_V1).Append(paymentConfirmId).ToString();

            return AdapayRequest.getRequestAdapay(requestParams, uri, null);
        }

        /**
         * 钱包余额支付
         *
         * @param requestParams      要查询的支付确认对象参数
         * @param merchantKey merchantKey
         * @return 查询的支付撤销对象
         */
        public static Dictionary<string, Object> createPage(Dictionary<string, object> requestParams)
        {
            return AdapayRequest.getRequestAdapay(requestParams, APIUrlEnum.CREATE_PAGE_PAYMENT, null);
        }

    }

    public class Bill
    {
        /**
         * download  bill file 
         */
        public static Dictionary<string, Object> download(Dictionary<string, object> requestParams)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.BILL_DOWNLOAD_V1, null);

        }

        /**
         * download  bill file 
         */
        public static Dictionary<string, Object> download(Dictionary<string, object> requestParams, string merchantKey)
        {

            return AdapayRequest.requestAdapay(requestParams, APIUrlEnum.BILL_DOWNLOAD_V1, merchantKey);

        }
    }
}
